@@ -1,6 +1,6 @@
+from __future__ import print_function
 
-
-PREVIOUS_VERSION = '0.25.0' ### We need to change this to point to the next version
+PREVIOUS_VERSION = '0.26.0'
 
 
 def main():
